Middleware

Struct Middleware 

pub struct Middleware<State, CTX: Debug, Request: Debug, Response: Debug, Error> { /* private fields */ }

Implementations

Source

impl<State: 'static + Send + Sync, CTX: 'static + Send + Sync + Debug, Request: 'static + Send + Sync + Debug, Response: 'static + Send + Sync + Debug, Error: 'static + Send + Sync> Middleware<State, CTX, Request, Response, Error>

pub fn new( middleware: Vec<Box<dyn MiddlewareChain<State, CTX, Request, Response, Error>>>, ) -> Self

Create a new Middleware execution chain.

Panics

This function will panic if the provided middleware vector is empty, as an empty chain cannot be unwrapped into an execution target.

pub async fn call( &self, state: State, ctx: CTX, request: Request, ) -> Result<Context<CTX, Request, Response>, Error>

Executes the middleware chain for the given request.

Errors

Returns an error if any MiddlewareChain in the execution pipeline fails while processing the state or request context.